@@ -37,7 +37,7 @@ class BaseIncubator:
   ##  Reparent an object
   ##
   def reparentObject(self, rootObject, object, newParent):
-    if object._parent == newParent:
+    if object.getParent () == newParent:
       return
 
     # TODO
@@ -105,7 +105,7 @@ class BaseIncubator:
   def deleteObject(self, rootObject, object, newCurrentObject=None, firstRun=1):
 
     if firstRun:
-      newCurrentObject = parent = object._parent
+      newCurrentObject = parent = object.getParent ()
 
     for child in object._children:
       if not child._type == '_content_':
@@ -115,9 +115,9 @@ class BaseIncubator:
 
     if firstRun:
       o = parent
-      while o._parent:
+      while o.getParent ():
         o._buildObject()
-        o = o._parent
+        o = o.getParent ()
 
       if newCurrentObject:
         self.instance.dispatchEvent('ObjectSelected',object=object, originator=__name__)
