@@ -31,7 +31,6 @@
 __all__ = ['BaseInstance']
 
 import sys, os, time, dircache, string
-from wxPython.wx import *
 from gnue.common.apps import GDebug
 from gnue.common.apps import RuntimeSettings
 from gnue.common.utils.FileUtils import dyn_import
@@ -39,18 +38,14 @@ from gnue.common.events import EventController, Event
 from gnue.designer.base.MenuBar import MenuBar
 from gnue.designer.base.UndoManager import UndoManager
 from gnue.designer.base.ToolBase import ToolBase
-from gnue.designer.base.docks.Docker import Docker
 from gnue.designer.base.ObjectList import ObjectList
 from gnue.designer.base import TemplateBase
 from gnue.designer.base.TemplateParser import WizardRunner
-from PrimaryToolBar import PrimaryToolBar
-from gnue.designer import VERSION, PACKAGE
+from gnue.designer import VERSION, PACKAGE as TITLE
 from ModuleSupport import SupportedModules
-from gnue.designer.base import Goat
 
-TITLE=PACKAGE
 
-class BaseInstance(wxFrame, EventController):
+class BaseInstance(EventController):
 
   ########################################################################
   #
@@ -109,11 +104,9 @@ class BaseInstance(wxFrame, EventController):
   # a hook of some sorts.
   #
   def __init__(self, app, location=None, buffer=None, style=None):
-    wxFrame.__init__(self, NULL, -1, "")
     EventController.__init__(self)
 
-    icon = Goat.getGoatIcon()
-    self.SetIcon(icon)
+    self.uiinstance = app.ui.createInstance(self)
 
     # During startup, we will cache all events
     # so we can execute them when everything has
@@ -139,7 +132,7 @@ class BaseInstance(wxFrame, EventController):
     self._makeBackup = True
     self._isNew = True
 
-    self._app = app
+    self._app = self.base = app
     self.connections = app.connections
     self.nameMappings = {}
     self.usedNames = []
@@ -180,33 +173,33 @@ class BaseInstance(wxFrame, EventController):
     else:
 
       if not os.access (location, os.R_OK):
-        self.Show(True)
-        if wxMessageDialog(self,
+        self.show()
+        if not self.base.ui.dialogYesNo(
           _('The requested file does not exist.\n') +
           _('Do you want to create this file?') +
           _('\n\nFile: %s') \
-            % location, _("File Not Found"), wxYES_NO|wxICON_QUESTION ).ShowModal() == wxID_NO:
+            % location, _("File Not Found"), self.uiinstance):
+          # TODO: Is this right?
           sys.exit()
-        self.Show(0)
+        self.hide()
         self.__createEmptyInstance(style)
         self._path = location
         self.makeDirty()
 
       elif not os.access (location, os.W_OK):
-        self.Show(True)
-        if wxMessageDialog(self, \
+        self.show()
+        if not self.base.ui.dialogCancel(
           _('The requested file is Read Only.\n') +
           _('To save any changes, you will \n') +
           _('be required to do a "Save As..."\n\nFile: %s') \
-            % location, _("Read Only Warning"), wxOK|wxCANCEL|wxICON_EXCLAMATION ).ShowModal() == wxID_CANCEL:
+            % location, _("Read Only Warning"), self.uiinstance) :
+          # TODO: Is this right?
           sys.exit()
-        self.Show(0)
+        self.hide()
         self.__loadFromFile(location)
       else:
         self.__loadFromFile(location)
 
-    self.statusbar = self.CreateStatusBar()
-    self.SetStatusText(_('Welcome to GNUe Designer -- Do not expose to direct sunlight, do not feed after midnight, and do not get wet.'))
     self.menubar = MenuBar(self)
 
 
@@ -224,14 +217,13 @@ class BaseInstance(wxFrame, EventController):
 
     self.createWizards()
     self.createTools()
-    self._initTools()
+    self.uiinstance.initTools()
 
     # Finalize menu bar
     self.menubar.finalize()
     self._app.mru.addMenu(self.menubar.getMenu('File|Open Recent|'), self)
 
-    self.toolbar = PrimaryToolBar(self, self)
-    self.SetToolBar(self.toolbar)
+    self.toolbar = self.uiinstance.toolbar
     self.initToolBar()
 
     # TODO: This is a hack to disable any menu items
@@ -240,33 +232,14 @@ class BaseInstance(wxFrame, EventController):
                    'RequestPaste','RequestPasteSpecial','RequestCut'):
       self.dispatchEvent('Disable:%s' % action)
 
-
-    # Build accelerator list
-    accel = wxAcceleratorTable(self.globalAccelerators)
-    for child in [self] + self.globalAcceleratorListeners:
-      child.SetAcceleratorTable(accel)
-
     # Add ourselve to the main app's instance list
     self._app.addInstance(self)
 
-    # Fit the widgets to the screen
-    self.Fit()
-
-    self.SetSize((
-       RuntimeSettings.getint(self.runtime_section, 'width', 550),
-       RuntimeSettings.getint(self.runtime_section, 'height', 400)))
-
-    self.SetPosition((
-       RuntimeSettings.getint(self.runtime_section, 'x', -1),
-       RuntimeSettings.getint(self.runtime_section, 'y', -1)))
 
     self.dispatchEvent('ObjectSelected', originator=self,
                        object=self.rootObject)
 
-    self.Show(true)
-    self.Refresh()
-
-    EVT_CLOSE(self, self.OnClose)
+    self.uiinstance.finalize()
 
     self.stopCachingEvents()
 
@@ -311,21 +284,18 @@ class BaseInstance(wxFrame, EventController):
 
     # Add supported tools to File|New
     for tool in SupportedModules:
-       self.menubar.addAction('File|New', '&%s' % tool.properties.nickname,'RequestNew', 100,
+      self.menubar.addAction('File|New', '&%s' % tool.properties.nickname,
+              'RequestNew', 100,
         help=_('Create a new %s') % string.lower(tool.properties.nickname), eventdata={'type': tool.properties.module })
 
     # Add connections
     for conn in self.connections.getAllConnectionParameters().keys():
-      id = wxNewId()
       self.menubar.addAction('File|Connect To', conn, 'Connect:%s' % conn,
                help=_("Login to %s connection") % conn,
                eventdata={'connection': conn})
       self.registerEventListeners({'Connect:%s' % conn:self.__OnConnectTo})
 
 
-  def _initTools(self):
-    self.docker = Docker(self, self, self._toolCache)
-
   def addTool(self, id, title, baseclass, hotkey=None, menuGroup=499):
     self._toolCache.append( (id, title, baseclass, hotkey, menuGroup) )
 
@@ -400,14 +370,7 @@ class BaseInstance(wxFrame, EventController):
   #  Used by RuntimeSettings
   #
   def saveRuntimeSettings(self):
-    x, y = self.GetPositionTuple()
-    width, height = self.GetSizeTuple()
-    settings = { 'x': abs(x),
-                 'y': abs(y),
-                 'height': height,
-                 'width': width  }
-
-    return ( self.runtime_section, settings )
+    return ( self.runtime_section, self.uiinstance.getRuntimeSettings() )
 
 
   # Do we need to be saved?
@@ -419,9 +382,9 @@ class BaseInstance(wxFrame, EventController):
     if not self._isdirty:
       self._isdirty = True
       if self._path == "":
-        self.SetTitle( TITLE + _(" - <New %s> *") % self.properties.nickname)
+        self.uiinstance.setTitle( _("<New %s> *") % self.properties.nickname)
       else:
-        self.SetTitle( TITLE + " - " + self._path + " *")
+        self.uiinstance.setTitle(self._path + " *")
     self.dispatchEvent('MakeDirty')
 
   # Mark our form as "clean" (no unsaved changes)
@@ -429,9 +392,9 @@ class BaseInstance(wxFrame, EventController):
     self._isdirty = 0
     self._isnew = 0
     if self._path == "":
-      self.SetTitle( TITLE + _(" - <New %s>") % self.properties.nickname)
+      self.uiinstance.setTitle( _("<New %s>") % self.properties.nickname)
     else:
-      self.SetTitle( TITLE + " - " + self._path)
+      self.uiinstance.setTitle( self._path)
     self.dispatchEvent('MakeClean')
 
 
@@ -449,7 +412,7 @@ class BaseInstance(wxFrame, EventController):
         if object.name:
           object._description = object.name + "(out:)"
         else:
-         object._description = object._xmltag + "(out:)"
+          object._description = object._xmltag + "(out:)"
 
       # Assign an ID if none exists
       # TODO: in the future, I want to change these to id=".." instead of name=".."
@@ -496,8 +459,8 @@ class BaseInstance(wxFrame, EventController):
     object = event.object
 
     # Delete the actual object from its parent
-    object._parent._children.remove(object)
-    ##object._parent._children.pop(object._parent._children.index(object))
+    object.getParent ()._children.remove(object)
+    ##object.getParent ()._children.pop(object.getParent ()._children.index(object))
 
     self.makeDirty()
 
@@ -599,66 +562,59 @@ class BaseInstance(wxFrame, EventController):
 
 
   def OnSaveAs(self, event):
-    wildcard = ""
+    wildcards = []
     # Make the "default" file extension for a tool
     # appear before the other extensions.
     filterIndex = [self.properties.defaultFileExtension]
-    wildcard += "%s (*.%s)|*.%s|" % \
-     ( self.properties.fileExtensions[self.properties.defaultFileExtension],
-       self.properties.defaultFileExtension,
-       self.properties.defaultFileExtension)
+    wildcards += [
+     ( self.properties.defaultFileExtension,
+       self.properties.fileExtensions[self.properties.defaultFileExtension]) ]
 
     for type in self.properties.fileExtensions.keys():
       if type != self.properties.defaultFileExtension:
-        wildcard += "%s (*.%s)|*.%s|" % \
-           ( self.properties.fileExtensions[type], type, type)
+        wildcards += [
+           ( type, self.properties.fileExtensions[type]) ]
         filterIndex.append(type)
 
-    dlg = wxFileDialog(self, _("Save %s As...") % self.properties.description, defaultDir=os.getcwd(),
-                           wildcard = wildcard,
-                           style=wxSAVE)
+    path = self.base.ui.dialogSaveFile(_("Save %s As...") % self.properties.description,
+                wildcards = wildcards,
+                parentWindow=self.uiinstance)
 
-    if dlg.ShowModal() == wxID_OK:
-      path = dlg.GetPath()
-      if len(path) < 4 or not (path[-4] == '.' and string.lower(path[-3:]) in self.properties.fileExtensions.keys()):
-        path += "." + filterIndex[dlg.GetFilterIndex()]
+    if path:
+#       if len(path) < 4 or not (path[-4] == '.' and string.lower(path[-3:]) in self.properties.fileExtensions.keys()):
+#         path += "." + filterIndex[dlg.GetFilterIndex()]
 
       if os.path.isfile(path):
-        dlg = wxMessageDialog(NULL,
+        overwrite = self.base.ui.dialogYesNo(
               _('The file "%s".\n' % path) +
               _("exists. Overwrite?"),
-              _("Unsaved Changes"), style=wxYES_NO|wxICON_WARNING)
-        save = dlg.ShowModal()
-        dlg.Destroy()
-        if save == wxID_NO:
+              _("Unsaved Changes"), icon="warn", parentWindow=self.uiinstance)
+        if not overwrite:
           self.OnSaveAs(event)
           return
 
       self._path = path
-      self.SetTitle (TITLE + " - " + self._path)
+      self.uiinstance.setTitle (self._path)
       self.save()
 
-    dlg.Destroy()
 
 
   def OnClose(self, event):
     if self.isDirty():
-      dlg = wxMessageDialog(NULL,
+      save = self.base.ui.dialogYesNoCancel(
               _("This document has unsaved changes.\n") +
               _("Save changes before closing?"),
-              _("Unsaved Changes"), style=wxYES_NO|wxCANCEL|wxICON_WARNING)
-      save = dlg.ShowModal()
-      dlg.Destroy()
-      if save == wxID_YES:
+              _("Unsaved Changes"), icon="warn", parentWindow=self.uiinstance)
+      if save == True:
         self.OnSave(event)
-      elif save == wxID_CANCEL:
+      elif save == -1:
         event.Veto()
         return
 
     RuntimeSettings.saveRuntimeSettings(self)
     self._app.mru.removeMenu(self.menubar.getMenu('File|Open Recent|'), self)
     self._app.removeInstance(self)
-    self.Destroy()
+    self.uiinstance.close()
 
 
   #################################################################
@@ -731,6 +687,8 @@ class GObjectHelper:
     self.instance.dispatchEvent('ObjectModified',
        object = object, new={key:value}, old=ov, originator = '__inline__')
 
+  def setStatus(self, text):
+    self.uiinstance.setStatus(text)
 
 #
 # Helper class used by the tool-specific packages
