@@ -31,8 +31,14 @@ import os
 from gnue.common.apps import RuntimeSettings
 from wxPython import wx
 
-class MRUManager: 
-  def __init__(self, app): 
+class MRUManager:
+  """
+  Most Recently Used (MRU) Manager
+
+  Responsible for maintaining the menu that displays the most
+  recently used items.
+  """
+  def __init__(self, app):
     self._menus = []
     self._locations = []
     self.menulist = []
@@ -56,31 +62,37 @@ class MRUManager:
     self._refreshMenuList()
 
 
-  def addLocation(self, location): 
+  def addLocation(self, location):
+    """
+    Adds a URL to the MRU list.
+    @type location: string
+    @param location: URL to be added
+    """
+
+    # Remove entry from old position
     absloc = os.path.normcase(os.path.abspath(location))
     try:
       self._locations.remove(absloc)
     except ValueError:
       pass
-    ## for i in range(len(self._locations)): 
-##       if self._locations[i] == absloc: 
-##         self._locations.pop(i)
-##         break
 
+    # Add to top of list
     self._locations.insert(0, absloc)
 
-    if len(self._locations) >= self._maxMRUs: 
+    # Truncate list if necessary
+    if len(self._locations) >= self._maxMRUs:
       self._locations = self._locations[:self._maxMRUs]
- 
+
     self._refreshMenuList()
 
 
   def _refreshMenuList(self):
-    # This figures out the common prefix of all the forms and reduces appropriately.
-    # i.e., if you have /usr/home/me/form1.gfd, /usr/home/you/form2.gfd then
-    # this will reduce to me/form1.gfd and you/form2.gfd.. This is to keep the
-    # MRU menu list from being too wide!
-
+    """
+    This figures out the common prefix of all the forms and reduces appropriately.
+    i.e., if you have /usr/home/me/form1.gfd, /usr/home/you/form2.gfd then
+    this will reduce to me/form1.gfd and you/form2.gfd.. This is to keep the
+    MRU menu list from being too wide!
+    """
     commonpos=len(os.path.commonprefix(
        map(lambda x: os.path.join(os.path.split(x)[0],''),self._locations)))
 
@@ -91,47 +103,73 @@ class MRUManager:
 
     self.refreshMenus()
 
-
   def addMenu(self, menu, instance):
+    """
+    Adds a link to a wxMenu that needs maintained.
+
+    @type menu: wxMenu instance
+    @param menu: A menu that needs maintained
+    @type instance: BaseInstance or child
+    @param instance: A designer instance to which this menu belongs.  Designer creates
+                                 an instance for every file it currently has open.
+    """
     self._menus.append(menu)
     menu.__instance = instance
     self.refreshMenu(menu)
 
   def removeMenu(self, menu, instance):
+    """
+    Removes a wxMenu from the list of wxMenus that
+    contain recently opened files.
+
+    @type menu: wxMenu instance
+    @param menu: Menu that needs removed
+    @type instance: BaseInstance
+    @param instance: A designer instance to which this menu belongs.  Designer creates
+                                 an instance for every file it currently has open.  NOT USED?
+
+    """
     self._menus.remove(menu)
 
-
   def refreshMenus(self):
+    """
+    Iterates through all the wxMenus under management and refreshes
+    their list.
+    """
     map(self.refreshMenu, self._menus)
 
-
   def refreshMenu(self, menu):
-
-    # Rid ourselves of old entries
+    """
+    Resets and updates the wxMenu that displays the MRU list.
+    """
+    # Purge all entries from the existing wxMenu and
+    # reset the menu mapping
+    self.mruMenuMap = {}
     for i in menu.GetMenuItems():
       menu.Delete(i.GetId())
 
+    # Rebuild the menu with the current items.
     i = 0
     for location in self.menulist:
       tid = wx.wxNewId()
       menu.Append ( tid, '&%s %s' % (i+1, location),
                     _('Open "%s" in a new window') % self._locations[i] )
 
-      wx.EVT_MENU(menu.__instance, tid, self._app.OnOpenRecent)
+      wx.EVT_MENU(menu.__instance.uiinstance, tid, self._app.OnOpenRecent)
       self.mruMenuMap[tid] = self._locations[i]
       i += 1
 
-
-  #
-  #  Used by RuntimeSettings
-  #
   def saveRuntimeSettings(self):
+    """
+    Returns a dictionary used by Designer's instance of RuntimeSettings
+    to save the recently used urls
+
+    @rtype: dict of {position:URL}
+    @return: The recently used files.
+    """
     results = {}
 
     for i in range(len(self._locations)):
       results["%s" % i] = self._locations[i]
 
     return ( self.runtime_section, results )
-
-
-
