@@ -26,7 +26,6 @@
 # NOTES:
 
 import sys, os, string
-from wxPython.wx import *
 from gnue.common.apps import GDebug
 import MRUManager
 from ModuleSupport import SupportedModules
@@ -35,16 +34,15 @@ from ModuleSupport import SupportedModules
 #
 #
 
-class MenuBar(wxMenuBar):
+class MenuBar:
   def __init__(self, instance):
-    wxMenuBar.__init__(self)
     self.instance = instance
-    self.instance.SetMenuBar(self)
 
     self._menus = {}
     self._menuItems = {'':[]}
 
-    self._locationToWx= {}
+    print instance
+    self.uimenu = instance.uiinstance.createMenuBar()
 
 
   # Locations can be <loc>|<loc> where <loc> is <location>/<translation>@group
@@ -85,12 +83,6 @@ class MenuBar(wxMenuBar):
                                  eventdata, help))
 
 
-  #
-  # Return the wxMenu(Item) associated with a location
-  def getMenu(self, location):
-    return self._locationToWx[location]
-
-
 
   #
   # Called by Instance.py when the menu can finally be built
@@ -98,7 +90,7 @@ class MenuBar(wxMenuBar):
   def finalize(self):
     for group, order, text, isMenu, action, canToggle, canDisable, \
         icon, hotkey, eventdata, help in self._menuItems['']:
-      self.__setupMenu(self, action, text)
+      self.__setupMenu(None, action, text)
 
 
   #
@@ -111,49 +103,24 @@ class MenuBar(wxMenuBar):
     if not items:
       return
 
-    menu = wxMenu()
-    self._locationToWx[location] = menu
-    parent.AppendMenu(wxNewId(), text, menu)
+    if parent:
+      menu = self.uimenu.createSubMenu(text, location, parent)
+    else:
+      menu = self.uimenu.createMenu(text, location)
+
     items.sort()
     lastgroup = items[0][0]
 
     for group, order, text, isMenu, action, canToggle, canDisable, \
         icon, hotkey, eventdata, help in self._menuItems[location]:
       if group != lastgroup:
-        menu.AppendSeparator()
+        self.uimenu.createSeparator(menu)
         lastgroup = group
 
       if isMenu:
         self.__setupMenu(menu, action, text)
       else:
-        mid = wxNewId()
-        if hotkey:
-          text += '\t' + hotkey
-        item = wxMenuItem(menu, mid, text, help,
-                  (canToggle and [wxITEM_CHECK] or [wxITEM_NORMAL])[0])
-        if canToggle:
-          EVT_MENU(self.instance._app, mid,
-            lambda event, l=self.instance, m=item, e=action, x=eventdata:
-                  l.dispatchEvent('%s:%s' % (m.IsChecked() and 'Show' or 'Hide',e), **x))
-          self.instance.registerEventListeners( {
-                   'Show:%s' % action:  lambda event, m=item: m.Check(1),
-                   'Hide:%s' % action: lambda event, m=item: m.Check(0) })
-        else:
-          EVT_MENU(self.instance._app, mid,
-            lambda event, l=self.instance, e=action, x=eventdata: l.dispatchEvent(e, **x))
-
-        if canDisable:
-          self.instance.registerEventListeners( {
-                   'Enable:%s' % action:  lambda event, m=item: m.Enable(1),
-                   'Disable:%s' % action: lambda event, m=item: m.Enable(0) })
-        menu.AppendItem(item)
-
-
-  #
-  # Convenience methods to make the main menu bar appear to be a menu container
-  #
-  def AppendMenu(self, wxId, text, menu):
-    self.Append(menu, text)
+        self.uimenu.createMenuItem(menu, text, canToggle, canDisable, icon, hotkey, eventdata, help, action)
 
 
   def getEventHelp(self, handle):
@@ -172,3 +139,10 @@ class MenuBar(wxMenuBar):
       pass
 
     return None
+
+  #
+  # Return the wxMenu(Item) associated with a location
+  def getMenu(self, location):
+    return self.uimenu.getMenu(location)
+
+
