@@ -22,11 +22,13 @@
 # ModuleSupport.py
 #
 # DESCRIPTION:
-#
+# 
 # NOTES:
 #
-
-
+"""
+Loads all modules available to designer.  
+Modules are only loaded once 
+"""
 from gnue.common.apps import GDebug as _GDebug
 from gnue.common.utils.FileUtils import dyn_import
 
@@ -34,8 +36,8 @@ SupportedModules = []
 UnsupportedModules = []
 Modules = (  'forms',
            'reports',
+           'schema',
 ##           'navigator',
-           'schema'
 )
 
 for module in Modules:
@@ -46,4 +48,3 @@ for module in Modules:
     UnsupportedModules.append(module)
     _GDebug.printMesg(1,'Cannot load Designer support for %s' % module)
     _GDebug.printMesg(2,'  Error: %s' % mesg)
-
