@@ -108,7 +108,7 @@ class ActionMenu(wxMenu):
     tid = wxNewId()
     self._newMap[tid] = tag
     self.Append(tid, text)
-    EVT_MENU(self.instance, tid, self.OnCreateObject)
+    EVT_MENU(self.instance.uiinstance, tid, self.OnCreateObject)
 
 
   def OnEditProperties(self, event):
@@ -125,7 +125,7 @@ class ActionMenu(wxMenu):
     attributes=hasattr(self,'Char__x') and {'Char:x': self.Char__x, 'Char:y': self.Char__y} or {}
     if tag == 'trigger':
       attributes['type']='named'
-      
+
     self.instance.incubator.createObject(self.instance.rootObject, tag,
       self._object, attributes)
 
@@ -236,26 +236,26 @@ class CreateObjectMenu(ActionMenu):
       self.instance.incubator.elementMapping[tag].sort()
       for element in self.instance.incubator.elementMapping[tag]:
         descr = string.upper(element[0])+string.lower(element[1:])
-        if descr == 'Import': 
+        if descr == 'Import':
           descr = 'Import Library'
-        elif len(descr) > 7 and descr[:7] == 'Import-': 
+        elif len(descr) > 7 and descr[:7] == 'Import-':
           descr = 'Imported ' + string.upper(descr[7])+ \
             string.lower(descr[8:])
 
         self.addCreateTag(element, descr)
-    
+
 
 
 # This menu is the popup menu on the object tree
-class ObjectMenu(ActionMenu): 
-  def __init__(self, instance, object): 
+class ObjectMenu(ActionMenu):
+  def __init__(self, instance, object):
     ActionMenu.__init__(self, instance, object, None, _("Object Tasks..."))
 
 
-     
+
 # This menu is the popup menu on the layout screen
-class PageMenu(ActionMenu): 
-  def __init__(self, instance, object, x, y): 
+class PageMenu(ActionMenu):
+  def __init__(self, instance, object, x, y):
     ActionMenu.__init__(self, instance, object, None, hasattr(object,'name') and \
        object.name or string.upper(object._type[2]) + \
        string.lower(object._type[3:]) )
