@@ -165,33 +165,45 @@ class TemplateBase:
     return self._connections.getConnection(connection_name,1)
 
 
-  def GetAvailableSources(self, connection_name):
+  def GetAvailableSources (self, connection_name):
 
-    if not self.__cachedSources.has_key(connection_name):
-      self.__cachedSources[connection_name] = \
-        self.GetTemporaryConnection(connection_name).introspector.find()
+    if not self.__cachedSources.has_key (connection_name):
+      self.__cachedSources [connection_name] = tables = \
+        self.GetTemporaryConnection (connection_name).readSchema ()
 
-    list = []
-    for schema in self.__cachedSources[connection_name]:
-      list.append ((schema.name,
-        hasattr(schema,'description') and schema.description or schema.name))
-    return list
+    result = []
+
+    if tables is not None:
+      for table in tables.findChildrenOfType ('GSTable', False, True):
+        result.append ((table.name, hasattr (table, 'description') and
+                                    table.description or table.name))
+    return result
 
 
-  def GetSourceSchema(self, connection_name, source_name):
-    return self.GetTemporaryConnection(connection_name)\
-               .introspector.findone(name=source_name)
+  def GetSourceSchema (self, connection_name, source_name):
+
+    if not connection_name in self.__cachedSources:
+      self.__cachedSources [connection_name] = \
+          self.GetTemporaryConnection (connection_name).readSchema ()
+
+    schema = self.__cachedSources [connection_name]
+    if schema is not None:
+      for table in schema.findChildrenOfType ('GSTable', False, True):
+        if table.name.lower () == source_name.lower ():
+          return table
+    else:
+      return None
 
 
-  def GetAvailableFields(self, connection_name, source_name):
-    list = []
-    source = self.GetSourceSchema(connection_name, source_name)
-    if source != None:
-      for schema in source.fields():
-        list.append((schema.name, hasattr(schema,'description') \
-                      and schema.description or schema.name))
+  def GetAvailableFields (self, connection_name, source_name):
+    result = []
+    source = self.GetSourceSchema (connection_name, source_name)
+    if source is not None:
+      for field in source.findChildrenOfType ('GSField', False, True):
+        result.append ((field.name, hasattr (field, 'description') \
+                      and field.description or field.name))
 
-    return list
+    return result
 
 
   def GetUniqueName(self, name, limitingObject=None):
