@@ -421,9 +421,9 @@ class ListField(wxListBox):
         set.append(self.mapping[v])
       self.SetSelections(set)
     else:
-      try: 
+      try:
         self.SetSelection(self.mapping[value])
-      except KeyError: 
+      except KeyError:
         pass
 
 
@@ -535,28 +535,28 @@ class SortableListField(wxPanel):
     if len(sel):
       self.delButton.Enable(1)
 
-      if 0 in sel: 
+      if 0 in sel:
         self.upButton.Enable(0)
-      else: 
+      else:
         self.upButton.Enable(1)
 
       if self.list2.Number()-1 in sel:
         self.downButton.Enable(0)
-      else: 
+      else:
         self.downButton.Enable(1)
     else:
       self.delButton.Enable(0)
       self.upButton.Enable(0)
       self.downButton.Enable(0)
-    
+
 
     self.addButton.Enable(0)
     for i in self.list1.GetSelections():
       self.list1.SetSelection(i,0)
 
   def OnSelectAll(self, event):
-    
-    count = self.list1.Number()
+
+    count = self.list1.GetCount()
     for count in range(count):
       self.list1.SetSelection(count)
     self.addButton.Enable(1)
@@ -581,12 +581,12 @@ class SortableListField(wxPanel):
     self.OnSelectRight(None)
 
 
-  def OnRemove(self, event): 
+  def OnRemove(self, event):
     sel = list(self.list2.GetSelections())
     sel.sort(lambda a,b : cmp (b,a))
     appendages1 = []
     appendages2 = []
-    for i in sel: 
+    for i in sel:
       appendages1.insert(0,self.list2.GetString(i))
       appendages2.insert(0,self.included[i])
       self.included.pop(i)
@@ -645,7 +645,7 @@ class WizardRunner:
     self.instance.dispatchEvent('BeginWizard', template=self.template)
     self.instance.dispatchEvent('BeginUndoGroup')
     self.parser = TemplateParser(self.instance, self.instance.rootObject,
-          self.instance, self.template)
+          self.instance.uiinstance, self.template)
     self.parser.run(*args, **parms)
     self.instance.dispatchEvent('EndUndoGroup')
     self.instance.dispatchEvent('EndWizard', template=self.template)
