@@ -124,8 +124,8 @@ class History:
   def __init__(self, manager, event):
     self.event = event
     if event.__event__ == 'ObjectDeleted':
-      self.parentindex = event.object._parent._children.index(event.object)
-      self.parent = id(event.object._parent)
+      self.parentindex = event.object.getParent ()._children.index(event.object)
+      self.parent = id(event.object.getParent ())
 
   def reverse(self, manager):
     orig = self.event
@@ -149,7 +149,7 @@ class History:
       for key, val in object.__dict__.items():
         if key[0] != '_' and type(val) != types.MethodType:
           attrs[key] = val
-      parent = manager.getCurrObject(object._parent)
+      parent = manager.getCurrObject(object.getParent ())
       obj = object.__class__(parent)
       obj.__dict__.update(attrs)
       obj._buildObject()
@@ -157,8 +157,8 @@ class History:
 
       # Move the child to its old, relative position
       # in the parent's child list
-      obj._parent._children.pop()
-      obj._parent._children.insert(self.parentindex, obj)
+      obj.getParent ()._children.pop()
+      obj.getParent ()._children.insert(self.parentindex, obj)
 
       # Notify our peeps...
       manager.instance.dispatchEvent('ObjectCreated', originator=__name__,
