@@ -473,7 +473,7 @@ class ReferencesViewer(wxPanel):
     for field in self.current._fieldFkReferences.keys():
       for item in self.current._fieldFkReferences[field]:
         addLine( self, "%s.%s" % (mastertable, field),
-                 "%s.%s" % (item._parent.name, item.name),
+                 "%s.%s" % (item.getParent ().name, item.name),
                  _("Dropdown Entry") )
 
 
@@ -570,25 +570,25 @@ class SchemaViewer(wxPanel):
     # TODO: albeit without schema support.
 
 
-    # TODO: This is the old, deprecated syntax
-    dataObject = self.editor.connections.getDataObject(conn, "object")
-
-    self.editor.connections.requestConnection(dataObject, conn)
-
-    schema = dataObject._connection.introspector.findone(name=self.editor.current.table)
-
+    c = self.editor.connections.getConnection (conn, True)
+    schema = c.readSchema ()(name=self.editor.current.table)
+    table  = None
+    if schema is not None:
+      for item in schema.findChildrenOfType ('GSTable', False, True):
+        if item.name.lower () == self.editor.current.table.lower ():
+          table = item
+          break
 
     index = 0
     self.list.DeleteAllItems()
-    if schema:
-      for field in schema.fields():
+    if table:
+      for field in table.findChildrenOfType ('GSField', False, True):
         self.list.InsertStringItem(index, field.name)
-        self.list.SetStringItem(index, SCH_TYPE,
-           string.upper(field.datatype[0]) + field.datatype[1:])
+        self.list.SetStringItem (index, SCH_TYPE, field.type.capitalize ())
         self.list.SetStringItem(index, SCH_NATIVE,
            hasattr(field, 'nativetype') and field.nativetype or '(unknown)')
         self.list.SetStringItem(index, SCH_REQ,
-           field.required and "Yes" or "No")
+           field.nullable and "No" or "Yes")
         if hasattr(field,'length'):
           if hasattr(field,'precision') and field.precision > 0:
             self.list.SetStringItem(index, SCH_SIZE, "%s;%s" % (
@@ -641,8 +641,8 @@ class SchemaViewer(wxPanel):
                      string.join(string.split(string.capwords( \
                        string.replace(object.name,'_',' '))),''))),
           "field": object.name,
-          "datatype": object.datatype,
-          "required" : object.required,
+          "datatype": object.type,
+          "required" : not object.nullable,
         }
 
       if hasattr(object,'length') and object.length:
