@@ -35,7 +35,7 @@ from gnue.common.formatting import GTypecast
 from gnue.common.logic.GTrigger import GTrigger
 from gnue.common.definitions.GParserHelpers import GContent
 from gnue.designer.base.ToolBase import *
-from gnue.designer.base.uihelpers.GridCellEditors import CharCellEditor
+from gnue.designer.uidrivers.wx.uihelpers.GridCellEditors import CharCellEditor
 
 class EventEditor (ToolBase):
 
@@ -299,7 +299,7 @@ class InspectorPanel(wxPanel):
 
 
   def _generateName(self, object):
-    parent = object._parent
+    parent = object.getParent ()
     name = '%s.%s (%s-Level Trigger)' % (parent.name, parent._validTriggers[object.type.upper()], parent._type[2:].capitalize())
     return name
 
