@@ -50,6 +50,7 @@ __all__ = ['SchemaNavigator']
 import sys, os, cPickle, traceback, StringIO, string, types
 from wxPython.wx import *
 from wxPython.gizmos import *
+from wxPython.wx import __version__ as wxversion
 from gnue.common.apps import GDebug
 from gnue.common.datasources import GDataSource
 from gnue.common.apps import RuntimeSettings
@@ -125,11 +126,14 @@ class SchemaNavigator(ToolBase):
     self.OnBeginDrag(event, right=1)
 
   def OnSelectionChange(self, event):
-    o = self.tree.GetPyData(event.GetItem())
-    if o.getColumn():
-      self.setFeedback(o.getLabel() + ':  ' + o.getColumn())
-    else:
-      self.setFeedback('')
+    try:
+      o = self.tree.GetPyData(event.GetItem())
+      if o.getColumn():
+        self.setFeedback(o.getLabel() + ':  ' + o.getColumn())
+      else:
+        self.setFeedback('')
+    except:
+      pass
 
   def __addTable(self, object):
     # Find the "connection" node
@@ -182,7 +186,10 @@ class SchemaNavigator(ToolBase):
         if not table.expanded:
           table.expand()
         cookie = 0
-        child, cookie = self.tree.GetFirstChild(table.node, cookie)
+        if wxversion[:3] == '2.6':
+          child, cookie = self.tree.GetFirstChild(table.node)
+        else:
+          child, cookie = self.tree.GetFirstChild(table.node, cookie)
         while child.IsOk():
           fields.append(self.__addField(self.tree.GetPyData(child)))
           child, cookie = self.tree.GetNextChild(table.node, cookie)
@@ -239,43 +246,36 @@ class ConnectionNode(Node):
     self.expanded = 1
     connection = self.navigator.connections.getConnection(self.connection, login=1)
 
-    schemaTypes = connection.introspector.types[:]
+    schema = connection.readSchema ()
 
-    if not schemaTypes:
+    if schema is None:
       return
 
-    schemaTypes.sort()
-    for schema, name, keep in schemaTypes:
-      if keep:
-        SchemaTypeNode(self.navigator, self.tree, self.node,
-                       introspector=connection.introspector, type=schema, name=name)
+    for tables in schema.findChildrenOfType ('GSTables', False, True):
+      SchemaTypeNode (self.navigator, self.tree, self.node, tables = tables)
 
-  def getLabel(self):
+
+  def getLabel (self):
     return self.connection
 
-  def getColumn(self, i=0):
-    data = self.navigator.connections.getConnectionParameters(self.connection)
+  def getColumn (self, i=0):
+    data = self.navigator.connections.getConnectionParameters (self.connection)
     try:
       return data['comment'] + ' (' + data['provider'] + ')'
     except:
       return '(' + data['provider'] + ')'
 
 
-class SchemaTypeNode(Node):
-  def getLabel(self):
-    return self.name
-  def getColumn(self, i=0):
+class SchemaTypeNode (Node):
+  def getLabel (self):
+    return self.tables.name
+  def getColumn (self, i=0):
     return ""
-  def expand(self):
+  def expand (self):
     self.expanded = 1
-    tree = self.tree
-    schemas = self.introspector.find(type=self.type)
-    if not schemas:
-      return
-    schemas.sort()
-    for schema in schemas:
-      TableNode(self.navigator, self.tree, self.node,
-                schema=schema)
+
+    for table in self.tables.findChildrenOfType ('GSTable', False, True):
+      TableNode (self.navigator, self.tree, self.node, schema = table)
 
 
 class TableNode(Node):
@@ -285,11 +285,11 @@ class TableNode(Node):
     return ""
   def expand(self):
     self.expanded = 1
-    for field in self.schema.fields():
-      FieldNode(self.navigator, self.tree, self.node, field=field)
+    for field in self.schema.findChildrenOfType ('GSField', False, True):
+      FieldNode (self.navigator, self.tree, self.node, field = field)
 
 
-class FieldNode(Node):
+class FieldNode (Node):
   isleaf = 1
   def getLabel(self):
     return self.field.name
@@ -297,19 +297,19 @@ class FieldNode(Node):
   def getColumn(self):
     rv = ""
     data = []
-    rv += self.field.datatype.capitalize()
+    rv += self.field.type.capitalize ()
     try:
-      data.append(str(self.field.length))
+      data.append (str (self.field.length))
     except:
       pass
     try:
-      data.append(str(self.field.precision))
+      data.append (str (self.field.precision))
     except:
       pass
 ##    if data:
 ##      rv += '; Size: ' + string.join(data,',')
 
-    if self.field.required:
+    if not self.field.nullable:
       rv += "; Not Null"
 
     return rv
