@@ -133,27 +133,29 @@ class SchemaViewer(ToolBase):
 
       # Create a cache by connection to conserve database calls
       try:
-        schemaTypes, schemas = self.connectionCache[conn]
+        types, tables = self.connectionCache[conn]
       except KeyError:
-        dataObject = self.connections.getDataObject(conn, "object")
+        c = self.connections.getConnection (conn, True)
 
-        self.connections.requestConnection(dataObject, conn)
+        gstree = c.readSchema ()
+        types  = []
+        tables = None
 
-        schemaTypes = dataObject.types
-        schemas = dataObject.find()
-        schemas.sort()
+        if gstree is not None:
+          for item in gstree.findChildrenOfType ('GSTables', False, True):
+            types.append (item.name)
+          tables = gstree.findChildrenOfType ('GSTable', False, True)
 
-        self.connectionCache[conn] = (schemaTypes, schemas)
+        self.connectionCache[conn] = (types, tables)
 
 
       index = 0
       self.list.DeleteAllItems()
 
-      for schema in schemas:
+      for schema in tables:
 
         self.list.InsertStringItem(index, schema.name)
-        self.list.SetStringItem(index, 1,
-           schema.type)
+        self.list.SetStringItem(index, 1, schema.type)
         self.list.SetItemData(index, index)
         index += 1
 
@@ -357,7 +359,7 @@ class ChildSchemaViewer(wxPanel):
 
         self.list.InsertStringItem(index, field.name)
         self.list.SetStringItem(index, SCH_TYPE,
-           string.upper(field.datatype[0]) + field.datatype[1:])
+           string.upper(field.type[0]) + field.type[1:])
         self.list.SetStringItem(index, SCH_NATIVE,
            hasattr(field, 'nativetype') and field.nativetype or '(unknown)')
         self.list.SetStringItem(index, SCH_REQ,
@@ -421,8 +423,8 @@ class ChildSchemaViewer(wxPanel):
                      string.join(string.split(string.capwords( \
                      string.replace(object.name,'_',' '))),''))),
           "field": object.name,
-          "datatype": object.datatype,
-          "required" : object.required,
+          "datatype": object.type,
+          "required" : not object.nullable,
         }
 
       if hasattr(object,'length') and object.length:
