@@ -18,7 +18,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: TriggerEditor.py 7148 2005-03-10 12:45:16Z kilo $
+# $Id: TriggerEditor.py 7346 2005-04-12 09:15:02Z johannes $
 
 
 from wxPython.wx import *
@@ -102,7 +102,7 @@ class TriggerEditor (ToolBase):
                        originator = None)
       if trigger.type.upper() != 'NAMED':
         wxCallAfter(self.dispatchEvent,'ObjectSelected',
-                           object = trigger._parent,
+                           object = trigger.getParent (),
                            originator = None)
 
       self.editor.SetReadOnly(0)
@@ -197,10 +197,10 @@ class TriggerEditor (ToolBase):
     if trigger.type.upper() == 'NAMED':
       return trigger.name
     else:
-      parent = trigger._parent
+      parent = trigger.getParent ()
       name = '%s.%s' % (parent.name, parent._validTriggers[trigger.type.upper()])
       try:
-        name = parent._parent.name + '.' + name
+        name = parent.getParent ().name + '.' + name
       except:
         pass
       return '('+name+')'
