@@ -18,7 +18,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: Debugger.py 7255 2005-03-25 10:32:29Z kilo $
+# $Id: Debugger.py 7678 2005-07-03 17:14:08Z btami $
 
 """
 Support class to run/debug a form from within Designer.
@@ -64,7 +64,7 @@ class DebugSession:
                           connections=caller._app.connections, \
                           ui=DummyInterfaceModule, disableSplash=True, \
                           moduleName='gnue.forms.uidrivers.wx.UIdriver')
-      debugInstance.addDialogs()
+      #debugInstance.addDialogs()
       debugInstance.addFormFromBuffer(caller.rootObject.dumpXML(treeDump=True))
           
       #debugInstance.setForm(GFParser.loadFile(StringIO(caller.rootObject.dumpXML(treeDump=1)), debugInstance))
