@@ -18,12 +18,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: Instance.py 7065 2005-02-25 14:00:35Z kilo $
-
-"""
-Creates a "Form" instance.
-"""
-
+# $Id: Instance.py 7346 2005-04-12 09:15:02Z johannes $
 
 __all__ = ['Instance']
 
@@ -62,13 +57,16 @@ from gnue.common.apps import GDebug
 from gnue.common.datasources import GDataSource
 
 class Instance(BaseInstance, GFInstance.GFInstance):
-
+  """
+  Designer's form editor instance.  
+  """
   def __init__(self, app, *args, **params):
 
-    self.incubator = Incubator(self)
-    self.properties = formProperties
-    self.wizardRunner = WizardRunner
-    self.debugLevel = '1'
+    self.incubator = Incubator(self) # Incubator
+    self.properties = formProperties # List of the modules properties
+    self.wizardRunner = WizardRunner # 
+    self.debugLevel = '1'            # The debug level used when running a form
+                                     # inside designer
 
     # TODO: Can we make it so the GFInstance is not
     # TODO: part of the main Instance class, but an
@@ -136,9 +134,9 @@ class Instance(BaseInstance, GFInstance.GFInstance):
     if object._type == 'GFForm':
       object._blockMap = {}
     elif object._type == 'GFLogic':
-      object._parent._logic = object
+      object.getParent ()._logic = object
     elif object._type == 'GFLayout':
-      object._parent._layout = object
+      object.getParent ()._layout = object
       # Yes, you guessed it! More layout mgmt hackery...
       object._xmlchildnamespaces = {'Char':'GNUe:Layout:Char'}
     elif object._type == 'GFBlock':
@@ -152,7 +150,7 @@ class Instance(BaseInstance, GFInstance.GFInstance):
       object._block = self.rootObject._blockMap[object.block]
       object._field = object._block._fieldMap[object.field]
     elif isinstance(object, GFObjects.GFPage) and \
-        object._parent == self.rootObject:
+        object.getParent () == self.rootObject:
       self._pages.append(object)
 
     object._popupMenu = ObjectMenu(self, object)
@@ -193,7 +191,7 @@ class Instance(BaseInstance, GFInstance.GFInstance):
     elif object._type == 'GFField':
       del object.findParentOfType('GFBlock')._fieldMap[object.name]
     elif isinstance(object, GFObjects.GFPage) and \
-        object._parent == self.rootObject:
+        object.getParent () == self.rootObject:
       del self._pages[object]
 
     object._popupMenu = ObjectMenu(self, object)
