@@ -36,6 +36,10 @@ import cPickle
 # Drag and Drop support for our grid
 #
 class DisplayDropTarget(wxPyDropTarget):
+  TYPEMAP = {'date'    : 'date',
+             'datetime': 'date',
+             'time'    : 'date',
+             'number'  : 'number'}
 
   def __init__(self, editor):
     wxPyDropTarget.__init__(self)
@@ -343,7 +347,7 @@ class DisplayDropTarget(wxPyDropTarget):
 
       fattr = {'name': instance.getUniqueName('fld' + f['name'].capitalize()),
                'field':f['name'],
-               'typecast':f['datatype']}
+               'typecast': self.TYPEMAP.get (f['type'], 'text')}
 
       try:
         fattr['required'] = f['required']
