@@ -92,7 +92,6 @@ class LayoutEditor (ToolBase):
     self.backcolor = wxWHITE
 
     EVT_RIGHT_DOWN(self.notebook, self.onRightDown)
-    EVT_NOTEBOOK_PAGE_CHANGED(self,self.notebook.GetId(), self.OnPageSelected)
     EVT_SIZE(self, self.OnSize)
 
     self._currentObject = None
@@ -125,6 +124,9 @@ class LayoutEditor (ToolBase):
                       })
 
     self.instance.rootObject.walk (self.inventoryObject)
+
+    # don't put this before walk on win32...
+    EVT_NOTEBOOK_PAGE_CHANGED(self,self.notebook.GetId(), self.OnPageSelected)
     try:
       self._setCurrentPage(self._notebookMap[0])
     except KeyError:
@@ -161,11 +163,12 @@ class LayoutEditor (ToolBase):
          pos=wxPoint(0,0),
          style=wxCLIP_CHILDREN|wxHSCROLL|wxVSCROLL|wxSUNKEN_BORDER)
 
-      EVT_SIZE(self.workspacescroll, self.__OnGridSize)
       self.workspace = wxPanel(self.workspacescroll,-1)
       self.workspace.SetBackgroundColour(self.backcolor)
 
       self.notebook.AddPage(self.workspacescroll, wxEncode(object.name))
+      # don't put this before AddPage on win32...
+      EVT_SIZE(self.workspacescroll, self.__OnGridSize)
 
       object.__workspace = self.workspace
       self.drawPage(object)
@@ -726,8 +729,8 @@ class LayoutEditor (ToolBase):
       if event.ShiftDown():
         object = self._currentObject
         if hasattr(object,'_widgetHandler') and not object._type == 'GFPage':
-          i = object._parent._children.index(object)
-          lst = object._parent._children[i:] + object._parent._children[:i]
+          i = object.getParent ()._children.index(object)
+          lst = object.getParent ()._children[i:] + object.getParent ()._children[:i]
         else:
           lst = self.page._children[:]
         lst.reverse()
@@ -740,8 +743,8 @@ class LayoutEditor (ToolBase):
       elif not event.ControlDown() and not event.AltDown():
         object = self._currentObject
         if hasattr(object,'_widgetHandler') and not object._type == 'GFPage':
-          i = object._parent._children.index(object)
-          lst = object._parent._children[i+1:] + object._parent._children[:i+1]
+          i = object.getParent ()._children.index(object)
+          lst = object.getParent ()._children[i+1:] + object.getParent ()._children[:i+1]
         else:
           lst = self.page._children[:]
         for newobj in lst:
