@@ -599,8 +599,8 @@ class Workspace(wxPanel):
       if event.ShiftDown():
         object = self._currentObject
         if hasattr(object,'_widgetHandler') and not object._type == 'GFPage':
-          i = object._parent._children.index(object)
-          lst = object._parent._children[i:] + object._parent._children[:i]
+          i = object.getParent ()._children.index(object)
+          lst = object.getParent ()._children[i:] + object.getParent ()._children[:i]
         else:
           lst = self.page._children[:]
         lst.reverse()
@@ -613,8 +613,8 @@ class Workspace(wxPanel):
       elif not event.ControlDown() and not event.AltDown():
         object = self._currentObject
         if hasattr(object,'_widgetHandler') and not object._type == 'GFPage':
-          i = object._parent._children.index(object)
-          lst = object._parent._children[i+1:] + object._parent._children[:i+1]
+          i = object.getParent ()._children.index(object)
+          lst = object.getParent ()._children[i+1:] + object.getParent ()._children[:i+1]
         else:
           lst = self.page._children[:]
         for newobj in lst:
