@@ -84,34 +84,34 @@ class TreeView (BaseTreeView):
     if object != self.rootObject:
       icon = 'properties'
       if isinstance(object, GFObjects.GFOptions) and \
-         object._parent == self.rootObject:
+         object.getParent () == self.rootObject:
         object._treeItem = self.rootObject._treeItemFormProperties
         icon = 'properties'
       elif object._type in ('GFLogic','GFLayout') and \
-           object._parent == self.rootObject:
+           object.getParent () == self.rootObject:
         pass
       else:
-        parentTreeItem = object._parent._treeItem
+        parentTreeItem = object.getParent ()._treeItem
         if isinstance(object, GTrigger.GTrigger) and \
            object.type == 'NAMED':
           parentTreeItem = self.rootObject._treeItemNamedTriggers
           icon = 'trigger'
         elif isinstance(object, GTrigger.GTrigger):
 
-          if not hasattr(object._parent,'_treeItemTrigger'):
-            object._parent._treeItemTrigger = \
-              self.AppendItem(object._parent._treeItem, _("Events"))
+          if not hasattr(object.getParent (),'_treeItemTrigger'):
+            object.getParent ()._treeItemTrigger = \
+              self.AppendItem(object.getParent ()._treeItem, _("Events"))
             #self.tree.SetItemImage(object._parent._treeItemTrigger, treeIconMap['trigger'])
 
 
-          parentTreeItem = object._parent._treeItemTrigger
+          parentTreeItem = object.getParent ()._treeItemTrigger
           icon = 'trigger'
         elif isinstance(object, GFObjects.GFDataSource) or \
            isinstance(object, GDataSource.GConnection):
           parentTreeItem = self.rootObject._treeItemDataSources
           icon = 'datasource'
         elif isinstance(object, GFObjects.GFPage) and \
-             object._parent == self.rootObject:
+             object.getParent () == self.rootObject:
           icon = 'page'
         elif object._type in ('GFBlock',):
           icon = 'block'
