@@ -31,7 +31,7 @@
 
 from gnue.designer.forms.TemplateSupport import *
 from gnue.designer import VERSION
-from gnue.common.schema.Objects import *
+from gnue.common.datasources import GSchema
 import string
 
 
@@ -104,8 +104,8 @@ class CreateSchemaWizard(FormTemplate):
   def Finalize(self):
 
     self.tablelist = {}
-    self.schema = GSSchema()
-    self.gstables = GSTables(self.schema)
+    self.schema = GSchema.GSSchema()
+    self.gstables = GSchema.GSTables(self.schema)
 
     # Create Tables out of <datasource> tags
     self.form.walk(self.CreateTables)
@@ -134,10 +134,10 @@ class CreateSchemaWizard(FormTemplate):
         # add the table
         #
 
-        newtable = GSTable(self.gstables)
+        newtable = GSchema.GSTable(self.gstables)
         newtable.name=obj.table
-        GSFields(newtable)
-        GSConstraints(newtable)
+        GSchema.GSFields(newtable)
+        GSchema.GSConstraints(newtable)
         self.tablelist[string.lower(obj.name)]=newtable
 
       else:
@@ -239,13 +239,14 @@ class CreateSchemaWizard(FormTemplate):
           table=self.tablelist[string.lower(obj.name)]
 
           # create a foreign key on this table
-          newconstraint=GSConstraint(table.findChildOfType('GSConstraints'))
+          newconstraint=GSchema.GSConstraint ( \
+              table.findChildOfType ('GSConstraints'))
           newconstraint.name="fk_%s_%s" % (obj.table,obj.detaillink)
           newconstraint.type="foreignkey"
 
-          nfk_field=GSConstraintField(newconstraint)
+          nfk_field=GSchema.GSConstraintField(newconstraint)
           nfk_field.name=obj.detaillink
-          nfk_ref=GSConstraintRef(newconstraint)
+          nfk_ref=GSchema.GSConstraintRef(newconstraint)
           nfk_ref.name=obj.masterlink
 
           # create a field for that key, use string type for now
@@ -261,9 +262,9 @@ class CreateSchemaWizard(FormTemplate):
 
             oldpkey=mtable.findChildOfType("GSPKField")
             if oldpkey==None:
-              pkey=GSPrimaryKey(mtable)
+              pkey=GSchema.GSPrimaryKey(mtable)
               pkey.name="pk_%s_%s" % (mtable.name,obj.masterlink)
-              pkeyf=GSPKField(pkey)
+              pkeyf=GSchema.GSPKField(pkey)
               pkeyf.name=obj.masterlink
 
               # add field to master table, using default type
@@ -297,7 +298,7 @@ class CreateSchemaWizard(FormTemplate):
         return
 
     # create field
-    newfield = GSField(fields)
+    newfield = GSchema.GSField(fields)
     newfield.name=fieldname
     newfield.type=type
     if length!=None:
