@@ -160,11 +160,11 @@ class MasterTreeView(wxTreeCtrl):
   def inventoryObject(self, object):
     if object._type == 'GNParameter':
       return
-    if object._parent != None:
+    if object.getParent () != None:
 
       description = self.getName(object, 1)
 
-      object._treeItem = self.AppendItem(object._parent._treeItem, description)
+      object._treeItem = self.AppendItem(object.getParent ()._treeItem, description)
       self.SetPyData(object._treeItem, object)
       if object._type == 'GNProcess':
         self.SetItemBold(object._treeItem,1)
