@@ -34,7 +34,7 @@ from gnue.common.apps import GDebug
 from gnue.common.formatting import GTypecast
 from gnue.common.logic.GTrigger import GTrigger
 from gnue.common.definitions.GParserHelpers import GContent
-from gnue.designer.base.uihelpers.GridCellEditors import *
+from gnue.designer.uidrivers.wx.uihelpers.GridCellEditors.GridCellEditors import *
 from gnue.designer.base.ToolBase import *
 
 Columns = [  ('name','Name'),
@@ -193,7 +193,7 @@ class GroupEditor (ToolBase):
 
 
   def _generateName(self, object):
-    parent = object._parent
+    parent = object.getParent ()
     name = '%s.%s (%s-Level Trigger)' % (parent.name, parent._validTriggers[object.type.upper()], parent._type[2:].capitalize())
     return name
 
