@@ -44,7 +44,7 @@ class TreeView (BaseTreeView):
     if object != self.rootObject:
       # TODO: icons for reports wanted (btami)
       icon = 'properties'
-      parentTreeItem = object._parent._treeItem
+      parentTreeItem = object.getParent ()._treeItem
       if isinstance(object, GRParameters.GRParameters):
         icon = 'properties'
       elif isinstance(object, GRSortOptions.GRSortOptions):
