@@ -28,11 +28,11 @@
 #
 
 from gnue.common.apps import GDebug
-from gnue.common.schema import GSParser, Objects
+from gnue.common.datasources import GSchema
 from gnue.designer.base.Incubator import BaseIncubator
 
 class Incubator(BaseIncubator):
 
-  elements = GSParser.getXMLelements()
+  elements = GSchema.getXMLelements()
 
-  
\ No newline at end of file
+  
