@@ -29,7 +29,7 @@
 
 from gnue.designer.schema import properties as schemaProperties
 from gnue.designer.base.Instance import BaseInstance
-from gnue.common.schema import GSParser, Objects
+from gnue.common.datasources import GSchema
 from Incubator import Incubator
 import wizards
 
@@ -56,21 +56,21 @@ class Instance(BaseInstance):
 
 
   def loadBuffer(self, buffer):
-    schema = GSParser.loadFile (buffer, self, initialize=0)
+    schema = GSchema.loadFile (buffer, self, initialize=0)
     schema.name = 'schema'
     return schema
 
 
   def loadEmpty(self, style=None):
-    schema = Objects.GSSchema()
+    schema = GSchema.GSSchema()
     schema.title = "Untitled schema"
     schema.name = 'schema'
-    Objects.GSTables(schema)
+    GSchema.GSTables(schema)
     return schema
 
 
   def inventoryObject(self, object):
-    if isinstance(object, Objects.GSTables):
+    if isinstance(object, GSchema.GSTables):
       self.tables = object
     elif object._type == 'GSTable':
       self._tableMappings[object.name] = object
