@@ -28,11 +28,11 @@
 #
 
 from gnue.designer.base.TemplateBase import *
-from gnue.common.schema import Objects
+from gnue.common.datasources import GSchema
 
 # TODO
 def createRootObject(instance):
-  return Objects.GSSchema()
+  return GSchema.GSSchema ()
 
 
 
