@@ -41,7 +41,7 @@ class TreeView (BaseTreeView):
     if object != self.rootObject:
       icon = 'properties'
       try:
-        parentTreeItem = object._parent._treeItem
+        parentTreeItem = object.getParent ()._treeItem
       except AttributeError:
         parentTreeItem = None
         # TODO:
