@@ -54,6 +54,13 @@ class FormBuilderTemplate(FormTemplate):
   # The template parser will initially
   # call GetStep(FIRST_STEP).
   FIRST_STEP = '0'
+  TYPEMAP    = {'date'    : 'date',
+                'time'    : 'date',
+                'datetime': 'date',
+                'boolean' : 'boolean',
+                'number'  : 'number',
+                'string'  : 'text'}
+
 
 
   ###############
@@ -423,7 +430,7 @@ class FormBuilderTemplate(FormTemplate):
       # because we want to keep in the order that the user
       # specified
       fields = {}
-      for field in schema.fields():
+      for field in schema.findChildrenOfType ('GSField', False, True):
         if field.name in self.variables['tablefields%s' % count]:
           fields[field.name] = field
 
@@ -463,7 +470,7 @@ class FormBuilderTemplate(FormTemplate):
 
         attrs={ 'name': "fld%s" % fieldKey,
                 'field': field.name,
-                'typecast': field.datatype }
+                'typecast': self.TYPEMAP.get (field.type, 'text')}
 
         # If we have a length for the field, use this as the maxLength
         # for the entry. Also, adjust the display width if necessary.
