@@ -43,8 +43,14 @@ import string
 #
 
 
-class SimpleFormTemplate(FormTemplate):
+class SimpleFormTemplate (FormTemplate):
 
+  TYPEMAP    = {'date'    : 'date',
+                'time'    : 'date',
+                'datetime': 'date',
+                'boolean' : 'boolean',
+                'number'  : 'number',
+                'string'  : 'text'}
 
   # The first step in our wizard.
   # The template parser will initially
@@ -212,7 +218,7 @@ class SimpleFormTemplate(FormTemplate):
     # because we want to keep in the order that the user
     # specified
     fields = {}
-    for field in schema.fields():
+    for field in schema.findChildrenOfType ('GSField', False, True):
       if field.name in self.variables['fields']:
         fields[field.name] = field
 
@@ -252,7 +258,7 @@ class SimpleFormTemplate(FormTemplate):
 
       attrs={ 'name': "fld%s" % fieldKey,
               'field': field.name,
-              'typecast': field.datatype }
+              'typecast': self.TYPEMAP.get (field.type, 'text')}
 
       # If we have a length for the field, use this as the maxLength
       # for the entry. Also, adjust the display width if necessary.
