@@ -169,7 +169,7 @@ class SimpleReportTemplate(ReportTemplate):
     # because we want to keep in the order that the user
     # specified
     fields = {}
-    for field in schema.fields():
+    for field in schema.findChildrenOfType ('GSField', False, True):
       if field.name in self.variables['fields']:
         fields[field.name] = field
 
