@@ -176,7 +176,7 @@ class SimpleReportTemplate(ReportTemplate):
     # because we want to keep in the order that the user
     # specified
     fields = {}
-    for field in schema.fields():
+    for field in schema.findChildrenOfType ('GSField', False, True):
       if field.name in self.variables['fields']:
         fields[field.name] = field
 
@@ -188,10 +188,12 @@ class SimpleReportTemplate(ReportTemplate):
 
     for name in self.variables['fields']:
       field = fields[name]
-      attrs = {'width':field.length}
-      if field.datatype == 'number':
+      attrs = {}
+      if hasattr (field, 'length'):
+        attrs ['width'] = field.length
+      if field.type == 'number':
         attrs['align'] = "right"
-      elif field.datatype == 'date':
+      elif field.type in ['date', 'time', 'datetime']:
         attrs['align'] = "center"
       out_colhead = self.AddElement('out:colhead', out_tablehead, attrs, content=field.name)
 
@@ -202,9 +204,9 @@ class SimpleReportTemplate(ReportTemplate):
     for name in self.variables['fields']:
       field = fields[name]
       attrs = {}
-      if field.datatype == 'number':
+      if field.type == 'number':
         attrs['align'] = "right"
-      elif field.datatype == 'date':
+      elif field.type in ['date', 'time', 'datetime']:
         attrs['align'] = "center"
       out_col = self.AddElement('out:col', out_row, attrs)
       self.AddElement('field', out_col, {'name':field.name})
