@@ -134,6 +134,9 @@ class SchemaIntrospectionTemplate(SchemaTemplate):
 
     # Create the tables and fields...
     print "Adding <tables>"
+    # FIXME: this code is kind of obsolete, since self.GetSourceSchema already
+    #        returns a complete GSTable object tree. So the only thing needed
+    #        here would be add a clone of that tree to the local object tree
     tables = self.root.findChildOfType('GSTables') #self.AddElement('tables', self.root, {})
 
 
@@ -146,26 +149,27 @@ class SchemaIntrospectionTemplate(SchemaTemplate):
                                { 'name': tablename } )
 
       try:
-        primarykeys = schema.primarykey
+        primarykeys = schema.findChildOfType ('GSPrimaryKey')
       except:
-        primarykeys = []
+        primarykeys = None
 
       fields = self.AddElement('fields', table, {})
 
       # Add each field
-      for field in schema.fields():
+      for field in schema.findChildrenOfType ('GSField', False, True):
         print "  Adding <field> %s" % field.name
         attrs = { 'name': field.name,
-                  'type': field.datatype }
+                  'type': field.type }
 
         # Add length if appropriate for this datatype
+        # FIXME: this should be handled much more cleaner !!!
         try:
-          if field.datatype != 'date':
+          if field.type != 'date':
             attrs['length'] = int(field.length)
         except AttributeError:
-          if field.datatype == 'number':
+          if field.type == 'number':
             attrs['length'] = 12
-          elif field.datatype == 'text':
+          elif field.type == 'string':
             attrs['length'] = 200
 
         # ... precision
@@ -176,7 +180,7 @@ class SchemaIntrospectionTemplate(SchemaTemplate):
 
         # Add length if appropriate for this datatype
         try:
-          attrs['nullable'] = not field.required
+          attrs['nullable'] = field.nullable
         except AttributeError:
           attrs['nullable'] = 1
 
@@ -184,7 +188,7 @@ class SchemaIntrospectionTemplate(SchemaTemplate):
         if hasattr(field,'defaulttype'):
           if field.defaulttype == 'serial':
             attrs['defaultwith'] = 'serial'
-            if field.name in primarykeys and field.datatype == 'number':
+            if field.name in primarykeys and field.type == 'number':
               attrs['type'] = 'key'
           elif field.defaulttype == 'sequence':
             attrs['defaultwith'] = 'sequence'
@@ -202,10 +206,12 @@ class SchemaIntrospectionTemplate(SchemaTemplate):
       if primarykeys:
         pk = self.AddElement ('primarykey', table, {})
         pk.name='pk_%s' % tablename
-        for field in primarykeys:
+        for field in primarykeys.findChildrenOfType ('GSPKField', False, True):
           self.AddElement('pkfield', pk, {'name': field})
 
       # Add misc tags
+      # TODO: a GSTable instance as returned by GetSourceSchema () might
+      # already contain indices and constraints too!
       self.AddElement ('constraints', table, {})
       self.AddElement ('indexes', table, {})
 
